### Встроенные правила валидации ###
SVARX имеет некоторое число встроенных правил валидации.
Можно на основе стандартного API добавлять свои правила.
Переопределение стандартных правил также возможно, но крайне не рекомендуется и в будущем будет запрещено.

#### Общие принципы проверки ####
Для всех правил действуют несколько базовых принципов:

  * Никакие правила (кроме встроенного **required**) не проверяются на пустых полях.
  Пустым считается текстовый контрол ввода формы, значение (value) которого равно пустой строке.
  Не-текстовые контролы не считаются пустыми, даже если value равно ''.
  * Валидация несуществующих и disabled-полей всегда возвращает истину (если на правиле не указан спецатрибут **failifnull**)
  * Проверки с неизвестным **type** всегда возвращают истину 

В данный момент в jQuery-реализацию **встроены** следующие правила:

#### required ####
Требует, чтобы поле было заполнено (т.е. чтобы его value был отличен от пустой строки).
Для не-текстовых контролов (чекбоксов, радио) всегда возвращает истину.
Работу этого (очень важного) правила можно изменить, переопределив функцию **jQuery.fn.svarx.nonEmpty**.

#### email ####
Проверяет, что значение поля может являться адресом электронной почты.
Важно: т.к. описанные в RFC 5322 правила составления адресов e-mail практически никем не поддерживаются в полной мере, SVARX-проверка использует упрощённую форму этого правила на основе довольно простого регулярного выражения.
Следует понимать, что указание **type="email"** в SVARX-формате несёт скорее семантический смысл.
Для более аккуратных или специфичных проверок следует создавать свои правила валидации с отдельными именами.

#### regexp ####
Позволяет использовать для проверки подмножество PCRE, реализованное в JavaScript (jQuery-реализация SVARX обрабатывает регэкспы встроенными средствами браузера).
Это значит, что нельзя слепо копировать регэкспы, к примеру, из Perl из-за тонких различий между реализациями.

В случае использования проверки **regexp** у тега **&lt;rule /&gt;** появляются дополнительные атрибуты:
  
  * **match** — собственно регулярное выражение, без обрамляющих слешей и модификаторов.
  Обратите внимание, что внутри xml-атрибута необходимо превращать в enitity амперсанды и ломаные скобки.
  **match** проверяет совпадение с регэкспом всего значения целиком.
  * **partmatch** — аналог **match**, но проверяет совпадение по подстроке
  * **flags** — позволяет передать один или несколько флагов-модификаторов для регулярного выражения (одной строкой без разделителей, например **flags="i"** или **flags="ig"**).
  Любые флаги кроме **g**, **i** и **m** будут отфильтрованы.

Наличие **match** или **partmatch** является обязательным, **flags** — опционален. По умолчанию регэксп не получает никаких дополнительных флагов.

#### checked ####
Проверка для чекбоксов или радиобаттонов (для остальных всегда истинна). Проверяет наличие галочки (или пометки на радиокнопке).
ВАЖНО: для радобаттонов и чекбоксов часто используется одно имя для группы контролов.
Не забывайте использовать атрибут **item** на теге &lt;rule&gt; для указания того, какой именно элемент должен валидироваться.

#### selected ####
Аналог правила **checked** для селектов, одиночных и множественых.
Для одиночных селектов (type == &apos;select-one&apos;) проверка всегда истинна, если у &lt;rule&gt; не указан атрибут **option**, или если указанный номер элемента (опции) не существует. В противном случае проверяется, выделен ли элемент, номер которого указан в атрибуте **option**.
ВАЖНО: не надо путать атрибуты **option** и **item**. Первый — это специфичный для текущего правила атрибут, указывающий (по сути), о каком элементе &lt;option&gt; из селекта идёт речь.
Атрибут **item** — базовый атрибут, который можно использовать на любом теге &lt;rule&gt;, описание см. в описании тега &lt;rule&gt;.

#### eq ####
Проверяет, что два или более значения полей формы равны между собой. Позволяет выбрать строковое или числовое сравнение, а также игнорировать регистр символов.
Атрибуты тега &lt;rule&gt;:

  * **comparison=&quot;string|number&quot;** (по умолчанию **string**) задаёт тип сравнения
  * **nocase=&quot;yes&quot;** включает для строковых проверок режим игнорирования регистра символов

Эту проверку можно использовать только с полной формой записи тега &lt;rule&gt;, т.к. надо передавать на вход минимум 2 элемента (можно больше).

#### range ####
Позволяет задать минимум и максимум для значения.
Значение при этом воспринимается как нечто, что можно привести к числу вызовом функции parseFloat из JavaScript.
Если привести значение (хотя бы одно из проверяемых полей) к числу не удаётся, то проверка проваливается.
Атрибуты тега &lt;rule&gt;:

  * **min** — минимальное пороговое значение (ошибкой считается, если значение поля строго меньше указанной величины)
  * **max** - максимальное пороговое значение (ошибкой считается, если значение поля строго больше указанной величины)

Атрибуты **min** и **max** можно применять как вместе, так и по отдельности.
В случае указания только одного из этих атрибутов, второе пороговое значение не проверяется.
