#### О плагинах визуализации ####
Метод визуализации — это отдельный плагин «нижнего уровня», который реализует внешнюю реакцию страницы на события валидации.
Без такого плагина форма отправится даже при ошибке валидации, и никаких сообщений пользователь не увидит.
Такие плагины подключаются через простое API и получают от «ядра» SVARX-валидации всю необходимую информацию.

Плагин визуализации — это (в минимальном варианте) три публичных метода в пространстве **$.fn.svarx.methods.ИМЯ_МЕТОДА**.
Если на странице подключено несколько методов визуализации, укажите имя того, который вам нужен, с помощью параметра **method** при инициализации плагина.

Как мы знаем, параметр конфигурации bindTo определяет список событий, инициирующих SVARX-проверку (по умолчанию это только событие **submit**).
Эти события отслеживаются на форме, и при наступлении любого из них выполняется SVARX-валидация.
Выполнение происходит в три этапа, на каждом этапе генерируется кастомное событие и вызывается один из методов плагина визуализации. 

##### Этап 1, метод before #####
**$.fn.svarx.methods.ИМЯ_МЕТОДА.before = function(e, eventType) {}**
Вызывается событием **beforesvarx** на обрабатываемой форме.
Это значит: произошло одно из событий, перечисленных в параметре bindTo, и валидация готова начаться.
Какое именно событие вызвало валидацию, можно узнать по параметру eventType.

Не нужно путать eventType и e.type:

  * **eventType** указывает на событие, вызвавшее начало валидации (в большинстве случаев это будет **'submit'**, если вы ничего не меняли)
  * **e.type** — стандартное поле объекта Event из jQuery; указывает на имя текущего кастомного события и всегда содержит **'beforesvarx'**.

Обратите внимание: **this** всегда указывает на валидируемую форму.

Если внутри этого метода вызвать e.preventDefault(), то SVARX-валидация не будет выполнена.
Обработка события eventType продолжится как обычно.

##### Этап 2, множественный: метод error #####
**fn.svarx.methods.ИМЯ_МЕТОДА.error = function(e, errorId, eventType) {}**
Этот метод вызывается кастомным событием **svarxerror**.

В процессе валидации каждый раз, когда находится ошибка на элементе формы, на этом элементе (или на другом, если определён параметр errtarget) вызывается событие **svarxerror**.
Вызов происходит отдельно для каждого правила или группы правил, которое после валидации было расценено как ошибочное и у которого есть атрибут onerror="ID_ОШИБКИ".
Параметр errorId содержит идентификатор ошибки (атрибут **onerror** из SVARX-правила).
Если onerror не был определён, событие **svarxerror** для конкретного (даже вызвавшего ошибку валидации) правила не происходит вообще.

**this** всегда указывает на валидируемую форму, а e.target указывает на DOM-элемент формы, на котором произошло событие svarxerror.
Поскольку событие svarxerror добирается до формы через event bubbling, this и e.target в этом случае не одно и то же.

Именно этот метод (обычно) отвечает за показ ошибок валидации, т.к. только ему (в отличие от **before** и **after**) доступен контекст возникновения ошибки, т.е. как её идентификатор, так и элемент, на котором ошибка случилась.

##### Этап 3, метод after #####
**$.fn.svarx.methods.ИМЯ_МЕТОДА.after = function(e, validationResult, eventType) {}**
Вызывается кастомным событием **aftersvarx** на обрабатываемой форме.
SVARX-валидация уже выполнена, и её результат (булева переменная validationResult) уже доступен.
По параметру eventType можно узнать, какое из событий вызвало валидацию.
Если мы хотим не отправлять формы из-за ошибок валидации, нужно включить в этот метод такой код:

```javascript
if (!validationResult && eventType == 'submit') {
    e.preventDefault();
}

```

Это предотвратит отправку формы, если в ней найдены ошибки.
**ВАЖНО**: именно на плагине визуализации лежит обязанность остановить отправку формы при неудачной валидации.
Если этого не сделать, даже при наличии ошибок форма будет отправлена.
